@@ -4,7 +4,7 @@ from bs4 import BeautifulSoup
 import urllib2
 import os
 
-def downloadToMP3(subfolder="", url, folder):
+def downloadToMP3(url, folder, subfolder=""):
     video = pafy.new(url)
     best = video.getbest()
     folder = folder+subfolder
@@ -41,7 +41,7 @@ def downloadSong(artist, song, folder):
     songURL = "http://www.youtube.com" + data.find("a")['href']
     downloadToMP3(songURL, folder)
     
-def downloadTop(number=5, artist, folder):
+def downloadTop(artist, folder, number=5):
     artistRep = artist.replace(' ','+')
     url = "http://www.youtube.com/results?search_query="+artistRep+"&filters=video"
     soup = BeautifulSoup(urllib2.urlopen(url))
